flutter_heyteacher_timer_workflow library

Classes

FlutterHeyteacherTimerWorkflowLocalizations
Callers can lookup localized strings with an instance of FlutterHeyteacherTimerWorkflowLocalizations returned by FlutterHeyteacherTimerWorkflowLocalizations.of(context).
RunningTask<T extends TimerTask>
Represents the current state of a running TimerWorkflow.
TimerTask
Represents a single, timed task within a TimerWorkflow.
TimerWorkflow<T extends TimerTask>
Manages a sequential workflow of timed tasks.

Enums

WorkflowStatus
Represents the possible states of a TimerWorkflow.

Exceptions / Errors

WorkflowTaskAlreadyInitialized
An exception thrown when an attempt is made to initialize tasks in a workflow that has already been initialized.
WorkflowTaskNotInitialized
An exception thrown when an attempt is made to play a workflow that has not been initialized with any tasks.